@@ -2,12 +2,13 @@ use super::{
     deep_map, deep_map_preorder, deep_map_unwrap_preorder, prelude::*, visit_circuit,
     visit_circuit_fallable, HashBytes,
 };
+use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 use crate::pycall;
 use pyo3::{pyfunction, PyObject, Python};
-use std::collections::{HashMap, HashSet};
+
 pub fn filter_nodes(circuit: CircuitRc, filter: &dyn Fn(&Circuit) -> bool) -> HashSet<CircuitRc> {
     let mut result: HashSet<CircuitRc> = HashSet::new();
-    visit_circuit(&**circuit, |circuit| {
+    visit_circuit(&circuit, |circuit| {
         if filter(circuit) {
             result.insert(circuit.clone().rc());
         }
@@ -22,7 +23,7 @@ pub fn filter_nodes_py(
     filter: PyObject,
 ) -> Result<HashSet<CircuitRc>, CircuitConstructionError> {
     let mut result: HashSet<CircuitRc> = HashSet::new();
-    let err = visit_circuit_fallable(&**circuit, |circuit| {
+    let err = visit_circuit_fallable(&circuit, |circuit| {
         let filter_result: Result<_, CircuitConstructionError> =
             pycall!(filter, (circuit.clone().rc(),), CircuitConstructionError);
         let filter_result = filter_result?;
@@ -37,7 +38,7 @@ pub fn filter_nodes_py(
 #[pyfunction]
 #[pyo3(name = "replace_nodes")]
 pub fn replace_nodes_py(circuit: CircuitRc, map: HashMap<CircuitRc, CircuitRc>) -> CircuitRc {
-    deep_map_unwrap_preorder(&**circuit, |x: &Circuit| -> CircuitRc {
+    deep_map_unwrap_preorder(&circuit, |x: &Circuit| -> CircuitRc {
         let rc = x.clone().rc();
         map.get(&rc).cloned().unwrap_or(rc)
     })
@@ -46,7 +47,7 @@ pub fn replace_nodes_py(circuit: CircuitRc, map: HashMap<CircuitRc, CircuitRc>)
 /// Replaces child nodes recursively with a mapping
 /// In pre-order so that high level nodes are replaced first
 pub fn replace_nodes(circuit: CircuitRc, map: &HashMap<HashBytes, CircuitRc>) -> CircuitRc {
-    deep_map_unwrap_preorder(&**circuit, |x: &Circuit| -> CircuitRc {
+    deep_map_unwrap_preorder(&circuit, |x: &Circuit| -> CircuitRc {
         let rc = x.clone().rc();
         map.get(&rc.info().hash).cloned().unwrap_or(rc)
     })
@@ -59,7 +60,7 @@ pub fn deep_map_preorder_py(
     f: PyObject,
 ) -> Result<CircuitRc, CircuitConstructionError> {
     deep_map_preorder(
-        &**circuit,
+        &circuit,
         |x: &Circuit| -> Result<CircuitRc, CircuitConstructionError> {
             pycall!(f, (x.clone().rc(),), CircuitConstructionError)
         },
@@ -69,7 +70,7 @@ pub fn deep_map_preorder_py(
 #[pyfunction]
 #[pyo3(name = "deep_map")]
 pub fn deep_map_py(circuit: CircuitRc, f: PyObject) -> Result<CircuitRc, CircuitConstructionError> {
-    deep_map(&**circuit, &|x: &Circuit| -> Result<
+    deep_map(&circuit, &|x: &Circuit| -> Result<
         CircuitRc,
         CircuitConstructionError,
     > {
@@ -85,7 +86,7 @@ pub fn update_nodes_py(
     updater: PyObject,
 ) -> Result<CircuitRc, CircuitConstructionError> {
     let nodes = filter_nodes_py(circuit.clone(), matcher)?;
-    deep_map_preorder(&**circuit, |x| {
+    deep_map_preorder(&circuit, |x| {
         let xcloned = x.clone().rc();
         if nodes.contains(&xcloned) {
             pycall!(updater, (xcloned,), CircuitConstructionError)
@@ -150,7 +151,7 @@ pub fn update_path_py(
     path: CircuitPath,
     updater: PyObject,
 ) -> Result<CircuitRc, CircuitConstructionError> {
-    update_path(&**circuit, &path, |x| {
+    update_path(&circuit, &path, |x| {
         pycall!(updater, (x.clone().rc(),), CircuitConstructionError)
     })
 }
