@@ -340,8 +340,21 @@ impl GeneralFunction {
         spec_name: String,
         name: Option<String>,
     ) -> Result<Self, CircuitConstructionError> {
+        Self::new_by_name_op(nodes, spec_name.clone(), name)?
+            .ok_or(CircuitConstructionError::UnknownGeneralFunction { spec_name })
+    }
+
+    #[staticmethod]
+    pub fn new_by_name_op(
+        nodes: Vec<CircuitRc>,
+        spec_name: String,
+        name: Option<String>,
+    ) -> Result<Option<Self>, CircuitConstructionError> {
         let spec = GENERAL_FUNCTIONS_SPECS.get(&spec_name);
-        let spec = spec.ok_or(CircuitConstructionError::UnknownGeneralFunction { spec_name })?;
-        GeneralFunction::try_new(nodes, spec.clone(), name)
+        if spec.is_none() {
+            return Ok(None);
+        }
+
+        GeneralFunction::try_new(nodes, spec.unwrap().clone(), name).map(Some)
     }
 }
