@@ -5,7 +5,9 @@ use crate::{
     cached_lambda,
     py_types::{make_bytes_py, PyShape, Tensor},
     rearrange_spec::{OpSize, RearrangeSpec},
-    tensor_util::{Shape, Slice, TensorAxisIndex, TensorIndex, TorchDeviceDtype, TorchDeviceDtypeOp},
+    tensor_util::{
+        Shape, Slice, TensorAxisIndex, TensorIndex, TorchDeviceDtype, TorchDeviceDtypeOp,
+    },
     util::AsOp,
 };
 pub use computational_node::{
