@@ -90,26 +90,25 @@ pub struct Slice {
 impl Slice {
     pub fn to_unsigned_loc(x: i64, l: usize) -> usize {
         if x < 0 {
-            l.checked_sub((-x) as usize).unwrap()
+            l.saturating_sub((-x) as usize)
         } else {
-            assert!(x <= l as i64);
-            x as usize
+            l.min(x as usize)
         }
     }
 
-    pub fn start_u(self, l: usize) -> usize {
+    fn start_u(self, l: usize) -> usize {
         self.start.map(|x| Self::to_unsigned_loc(x, l)).unwrap_or(0)
     }
 
-    pub fn stop_u(self, l: usize) -> usize {
+    fn stop_u(self, l: usize) -> usize {
         self.stop.map(|x| Self::to_unsigned_loc(x, l)).unwrap_or(l)
     }
 
-    pub fn size(self, l: usize) -> usize {
+    fn size(self, l: usize) -> usize {
         self.stop_u(l).saturating_sub(self.start_u(l))
     }
 
-    pub fn canonicalize(self, l: usize) -> Self {
+    fn canonicalize(self, l: usize) -> Self {
         Self {
             start: Some(self.start_u(l) as i64),
             stop: Some(self.stop_u(l) as i64),
@@ -131,7 +130,7 @@ impl Slice {
         }
     }
 
-    pub fn is_identity(self, l: usize) -> bool {
+    fn is_identity(self, l: usize) -> bool {
         self.start_u(l) == 0 && self.stop_u(l) == l
     }
 }
